==> haskell-regex-tdfa-1.2.2-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-CVIYUGRss6A80AATdUvfD
key: regex-tdfa-1.2.2-CVIYUGRss6A80AATdUvfD
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: d76e8f1653d37ec29e9309bb7b602c86
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-CVIYUGRss6A80AATdUvfD
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    ghc-prim-0.5.1.1 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap
    regex-base-0.93.2-rcKBNTI69reeBx0eaPBC
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             parsec-3.1.13.0-E3xu0p0JtSPICcgXxkVqap=e5bced146b6517b43ed5d06001479bde
             regex-base-0.93.2-rcKBNTI69reeBx0eaPBC=d7d8f12e28b86f8254a2a5665d808c04
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.2.2-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-regex-tdfa.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza
key: regex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
indefinite: False
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.NewDFA.Tester Text.Regex.TDFA.NewDFA.Uncons
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
abi: c86b19e2cbd14fb97658a1d16e179a53
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/regex-tdfa-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-IlR0NGVTXzLcCTtImXEza
depends:
    array-0.5.2.0 base-4.10.1.0 bytestring-0.10.8.2 containers-0.5.10.2
    ghc-prim-0.5.1.1 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp
    regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             regex-base-0.93.2-2WymZ6oErYqGB0H6LBWVXT=26a1e2ecf2b8a4c9538db44096d202ad
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
